import click
import datetime
from random import randint
from math import floor
from flask.cli import with_appcontext

from .models import Proposal, db
from grant.milestone.models import Milestone
from grant.comment.models import Comment
from grant.utils.enums import ProposalStatus, Category, ProposalStageEnum
from grant.user.models import User


@click.command()
@click.argument('stage')
@click.argument('user_id')
@click.argument('proposal_id')
@click.argument('title')
@click.argument('content')
@with_appcontext
def create_proposal(stage, user_id, proposal_id, title, content):
    proposal = Proposal.create(stage=stage,
                               user_id=user_id,
                               proposal_id=proposal_id,
                               title=title,
                               content=content)
    db.session.add(proposal)
    db.session.commit()


@click.command()
@click.argument('count', type=int)
@with_appcontext
def create_proposals(count):
    user = User.query.filter_by().first()
    for i in range(count):
        if i < 5:
            stage = ProposalStageEnum.FUNDING_REQUIRED
        else:
            stage = ProposalStageEnum.COMPLETED
        p = Proposal.create(
            stage=stage,
            status=ProposalStatus.LIVE,
            title=f'Fake Proposal #{i}',
            content=f'My fake proposal content, numero {i}',
            brief=f'This is proposal {i} generated by "flask create-proposals"',
            category=Category.ACCESSIBILITY,
            target="123.456",
            payout_address="fake123",
            deadline_duration=100
        )
        p.date_published = datetime.datetime.now()
        p.team.append(user)
        db.session.add(p)
        db.session.flush()
        num_ms = randint(1, 9)
        for j in range(num_ms):
            m = Milestone(
                title=f'Fake MS {j}',
                content=f'Fake milestone #{j} on fake proposal #{i}!',
                date_estimated=datetime.datetime.now(),
                payout_percent=str(floor(1 / num_ms * 100)),
                immediate_payout=j == 0,
                proposal_id=p.id,
                index=j
            )
            db.session.add(m)
        for j in range(100):
            c = Comment(
                proposal_id=p.id,
                user_id=user.id,
                parent_comment_id=None,
                content=f'Fake comment #{j} on fake proposal #{i}!'
            )
            db.session.add(c)

    db.session.commit()
    print(f'Added {count} LIVE fake proposals')
